@@ -2,9 +2,9 @@
 
 import sys
 
-from fetcher import fetch_fasta, EntryNotFoundException
-from helper import print_help, VERSION
-from writer import write_to_file
+from .fetcher import fetch_fasta, EntryNotFoundException
+from .helper import print_help, VERSION
+from .writer import write_to_file
 
 
 def dispatch_and_run():
